@@ -65,11 +65,10 @@ Tvector find_common(const xmlpp::ustring& xpath,
 
   if (namespaces)
   {
-    for (xmlpp::Node::PrefixNsMap::const_iterator it = namespaces->begin();
-         it != namespaces->end(); ++it)
+    for (const auto& [prefix, ns_uri] : *namespaces)
       xmlXPathRegisterNs(ctxt,
-        reinterpret_cast<const xmlChar*>(it->first.c_str()),
-        reinterpret_cast<const xmlChar*>(it->second.c_str()));
+        reinterpret_cast<const xmlChar*>(prefix.c_str()),
+        reinterpret_cast<const xmlChar*>(ns_uri.c_str()));
   }
 
   auto result = xmlXPathEval((const xmlChar*)xpath.c_str(), ctxt);
@@ -140,11 +139,10 @@ xmlXPathObject* eval_common(const xmlpp::ustring& xpath,
 
   if (namespaces)
   {
-    for (xmlpp::Node::PrefixNsMap::const_iterator it = namespaces->begin();
-         it != namespaces->end(); ++it)
+    for (const auto& [prefix, ns_uri] : *namespaces)
       xmlXPathRegisterNs(ctxt,
-        reinterpret_cast<const xmlChar*>(it->first.c_str()),
-        reinterpret_cast<const xmlChar*>(it->second.c_str()));
+        reinterpret_cast<const xmlChar*>(prefix.c_str()),
+        reinterpret_cast<const xmlChar*>(ns_uri.c_str()));
   }
 
   auto xpath_value = xmlXPathEvalExpression(
@@ -206,7 +204,7 @@ xmlpp::ustring eval_common_to_string(const xmlpp::ustring& xpath,
   xmlXPathFreeObject(xpath_value);
   if (result)
   {
-    const xmlpp::ustring uresult(reinterpret_cast<const char*>(result));
+    xmlpp::ustring uresult(reinterpret_cast<const char*>(result));
     xmlFree(result);
     return uresult;
   }
@@ -449,7 +447,9 @@ ustring Node::eval_to_string(const ustring& xpath, const PrefixNsMap& namespaces
 
 ustring Node::get_namespace_prefix() const
 {
-  if(impl_->type == XML_DOCUMENT_NODE || impl_->type == XML_ENTITY_DECL)
+  if(impl_->type == XML_DOCUMENT_NODE ||
+     impl_->type == XML_HTML_DOCUMENT_NODE ||
+     impl_->type == XML_ENTITY_DECL)
   {
     //impl_ is actually of type xmlDoc or xmlEntity, instead of just xmlNode.
     //libxml does not always use GObject-style inheritance, so xmlDoc and
@@ -463,7 +463,7 @@ ustring Node::get_namespace_prefix() const
   else if (impl_->type == XML_ATTRIBUTE_DECL)
   {
     //impl_ is actually of type xmlAttribute, instead of just xmlNode.
-    const xmlAttribute* const attr = reinterpret_cast<const xmlAttribute*>(impl_);
+    auto attr = reinterpret_cast<const xmlAttribute*>(impl_);
     return attr->prefix ? (const char*)attr->prefix : "";
   }
   else if(impl_->ns && impl_->ns->prefix)
@@ -475,6 +475,7 @@ ustring Node::get_namespace_prefix() const
 ustring Node::get_namespace_uri() const
 {
   if(impl_->type == XML_DOCUMENT_NODE ||
+     impl_->type == XML_HTML_DOCUMENT_NODE ||
      impl_->type == XML_ENTITY_DECL ||
      impl_->type == XML_ATTRIBUTE_DECL)
   {
@@ -591,6 +592,7 @@ void Node::create_wrapper(xmlNode* node)
       break;
     }
     case XML_DOCUMENT_NODE:
+    case XML_HTML_DOCUMENT_NODE:
     {
       // do nothing. For Documents it's the wrapper that is the owner.
       break;
@@ -639,6 +641,7 @@ void Node::free_wrappers(xmlNode* node)
       node->_private = nullptr;
       return;
     case XML_DOCUMENT_NODE:
+    case XML_HTML_DOCUMENT_NODE:
       //Do not free now. The Document is usually the one who owns the caller.
       return;
     default:
